==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/content/messages/pt-BR/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Também visível para não membros deste espaço)',
    '<strong>Confirm</strong> post deletion' => '<strong>Confirma</strong> exclusão do post',
    '<strong>Move</strong> content' => '<strong> Mover  strong&gt; conteúdo</strong>',
    '<strong>Permalink</strong> to this post' => '<strong>Link permanente</strong> para este post',
    'Add a member to notify' => 'Adicionar um membro para notificar',
    'Archived' => 'Arquivado',
    'Attach Files' => 'Anexar arquivos',
    'Back to stream' => 'Voltar ao mural',
    'Cancel' => 'Cancelar',
    'Cancel Edit' => 'Cancelar Alteração',
    'Change to "Private"' => 'Tornar privado',
    'Change to "Public"' => 'Tornar público',
    'Content' => 'Conteúdo',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Tag de conteúdo com contentcontainer_id inválido atribuído.',
    'Content has been moved to {spacename}' => 'O conteúdo foi movido para {spacename}',
    'Content visibility' => 'Visibilidade do conteúdo',
    'Could not delete content!' => 'Não foi possível apagar o conteúdo!',
    'Could not find requested content!' => 'Não foi possível encontrar o conteúdo solicitado!',
    'Created at:' => 'Criado em:',
    'Created by me' => 'Criado por mim',
    'Creation time' => 'Hora de criação',
    'Delete' => 'Apagar',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Você realmente deseja excluir este post? Todos os comentários e curtidas serão perdidos!',
    'Edit' => 'Alterar',
    'Filter' => 'Filtro',
    'I\'m involved' => 'Onde eu estou envolvido',
    'Invalid content id given!' => 'Informado ID de conteúdo inválido!',
    'Invalid request method!' => 'Método de requisição inválido!',
    'Invalid space selection.' => 'Seleção de espaço inválida.',
    'Last update' => 'Última atualização',
    'Last updated {time}' => 'Ultima atualização {time}',
    'Load more' => 'Carregar mais',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Número máximo de itens fixados atingido!<br>Você só pode fixar até {count} itens de uma vez.',
    'Move content' => 'Mover conteúdo',
    'Move to archive' => 'Mover para arquivar',
    'No matches with your selected filters!' => 'Nada foi encontrado com os filtros utilizados!',
    'None' => 'Nenhum',
    'Nothing here yet!' => 'Nada aqui ainda!',
    'Notify members' => 'Notificar membros',
    'Permalink' => 'Link permanente',
    'Pin to top' => 'Fixar no topo',
    'Pinned' => 'Fixado',
    'Private' => 'Privado',
    'Public' => 'Público',
    'Specify who can see this content.' => 'Especifique quem pode ver este conteúdo.',
    'Submit' => 'Enviar',
    'Tag' => 'Etiqueta',
    'Target Space' => 'Espaço de destino',
    'The author of this content is not allowed to create private content within the selected space.' => 'O autor deste conteúdo não tem permissão para criar conteúdo privado dentro do espaço selecionado.',
    'The author of this content is not allowed to create public content within the selected space.' => 'O autor deste conteúdo não tem permissão para criar conteúdo público no espaço selecionado.',
    'The author of this content is not allowed to create this type of content within this space.' => 'O autor deste conteúdo não tem permissão para criar este tipo de conteúdo neste espaço.',
    'The content can\'t be moved to its current space.' => 'O conteúdo não pode ser movido para o espaço atual.',
    'The content has been archived.' => 'O conteúdo foi arquivado.',
    'The content has been deleted.' => 'O conteúdo foi apagado.',
    'The content has been unarchived.' => 'O conteúdo foi desarquivado.',
    'The given name is already in use.' => 'O nome informado já está em uso.',
    'The module {moduleName} is not enabled on the selected target space.' => 'O módulo {moduleName} não está ativado no espaço de destino selecionado.',
    'This action is disabled!' => 'Essa ação está desabilitada!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Este tipo de conteúdo não pode ser movido devido a uma configuração ausente do ID do módulo.',
    'This content type can\'t be moved.' => 'Este tipo de conteúdo não pode ser movido.',
    'This space is archived.' => 'Esse espaço está arquivado.',
    'This space is not visible!' => 'Esse espaço não é visível!',
    'Topics' => 'Tópicos',
    'Turn off notifications' => 'Desativar notificações',
    'Turn on notifications' => 'Ativar notificações',
    'Unarchive' => 'Desarquivar',
    'Unpin' => 'Desprender',
    'Updated' => 'Atualizado',
    'Visible also to unregistered users' => 'Visível também para usuários não registrados',
    'Visible only to you' => 'Visível apenas para você',
    'Visible to all Space members' => 'Visível para todos os membros do Espaço',
    'Visible to all signed in users' => 'Visível para todos os usuários conectados',
    'Visible to friends of {displayName}' => 'Visível para amigos de {displayName}',
    'Visible to you and {displayName}' => 'Visível para você e {displayName}',
    'Visible to your friends' => 'Visível para seus amigos',
    'With attachments' => 'Com anexos de arquivos',
    'You do not have the permission to move this content to the given space.' => 'Você não tem permissão para mover este conteúdo para o espaço fornecido.',
    'You do not have the permission to move this content.' => 'Você não tem permissão para mover este conteúdo.',
    'Your last edit state has been saved!' => 'Seu último estado de alteração foi salvo!',
    'in' => 'em',
    '<strong>Delete</strong> content?' => '',
    'Add tag...' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Confirm' => '',
    'Lock comments' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Select type...' => '',
    'Unlock comments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/content/messages/pt-BR/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Também visível para não membros deste espaço)',
    '(Also visible to people who are not logged in)' => '(Também visível para pessoas que não estão logadas)',
    '<strong>Delete</strong> content?' => '<strong>Excluir</strong> conteúdo?',
    '<strong>Move</strong> content' => '<strong> Mover  strong&gt; conteúdo</strong>',
    '<strong>Permalink</strong> to this post' => '<strong>Link permanente</strong> para este post',
    '<strong>Scheduling</strong> Options' => 'Opções de <strong>Agendamento</strong>',
    'Activate scheduling' => 'Ativar agendamento',
    'Add a member to notify' => 'Adicionar um membro para notificar',
    'Add tag...' => 'Adicionar tag...',
    'Advanced Content Search' => 'Pesquisa avançada de conteúdo',
    'Archived' => 'Arquivado',
    'Attach Files' => 'Anexar arquivos',
    'Back to stream' => 'Voltar ao mural',
    'Cancel' => 'Cancelar',
    'Cancel Edit' => 'Cancelar Alteração',
    'Cannot notify the author.' => 'Não é possível notificar o autor.',
    'Change to "Private"' => 'Tornar privado',
    'Change to "Public"' => 'Tornar público',
    'Comments are locked' => 'Comentários estão bloqueados',
    'Comments are unlocked' => 'Comments estão desbloqueados',
    'Configure' => 'Configurar',
    'Confirm' => 'Confirmar',
    'Content' => 'Conteúdo',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Tag de conteúdo com contentcontainer_id inválido atribuído.',
    'Content has been moved to {spacename}' => 'O conteúdo foi movido para {spacename}',
    'Could not find requested content!' => 'Não foi possível encontrar o conteúdo solicitado!',
    'Create as draft' => 'Criar como rascunho',
    'Created at:' => 'Criado em:',
    'Created by me' => 'Criado por mim',
    'Creation time' => 'Hora de criação',
    'Delete' => 'Excluir',
    'Deleted' => 'Excluído',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Deseja excluir este conteúdo, incluindo todos os comentários e anexos?<br><br>Observação: se uma entrada de fluxo foi criada usando um módulo, o conteúdo original ao qual esta entrada está vinculada também será excluído.',
    'Draft' => 'Rascunho',
    'Edit' => 'Editar',
    'Enable' => 'Habilitar',
    'Enabled' => 'Ativado',
    'Filter' => 'Filtro',
    'Hidden' => 'Oculto',
    'I\'m involved' => 'Onde eu estou envolvido',
    'Invalid content id given!' => 'Informado ID de conteúdo inválido!',
    'Invalid request method!' => 'Método de requisição inválido!',
    'Invalid space selection.' => 'Seleção de espaço inválida.',
    'Last update' => 'Última atualização',
    'Last updated {time}' => 'Ultima atualização {time}',
    'Load more' => 'Carregar mais',
    'Lock comments' => 'Bloquear comentários',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Número máximo de itens fixados atingido!<br>Você só pode fixar até {count} itens de uma vez.',
    'Move content' => 'Mover conteúdo',
    'Move to archive' => 'Mover para arquivar',
    'New Updates Available!' => 'Novas atualizações disponíveis!',
    'No matches with your selected filters!' => 'Nada foi encontrado com os filtros utilizados!',
    'No tags found for the given query' => 'Nenhuma tag encontrada para esta pesquisa',
    'None' => 'Nenhum',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Observação: Devido a razões técnicas, pode haver um atraso de alguns minutos.',
    'Nothing here yet!' => 'Nada aqui ainda!',
    'Notify members' => 'Notificar membros',
    'Permalink' => 'Link permanente',
    'Pin to top' => 'Fixar no topo',
    'Pinned' => 'Fixado',
    'Private' => 'Privado',
    'Public' => 'Público',
    'Publish draft' => 'Publicar rascunho',
    'Save as draft' => 'Salvar como rascunho',
    'Save scheduling' => 'Salvar agendamento',
    'Schedule publication' => 'Agendar publicação',
    'Scheduled for {dateTime}' => 'Agendado para {dateTime}',
    'Select type...' => 'Selecione o tipo...',
    'Specify who can see this content.' => 'Especifique quem pode ver este conteúdo.',
    'Submit' => 'Enviar',
    'Tag' => 'Etiqueta',
    'Target Space' => 'Espaço de destino',
    'The author of this content is not allowed to create private content within the selected space.' => 'O autor deste conteúdo não tem permissão para criar conteúdo privado dentro do espaço selecionado.',
    'The author of this content is not allowed to create public content within the selected space.' => 'O autor deste conteúdo não tem permissão para criar conteúdo público no espaço selecionado.',
    'The author of this content is not allowed to create this type of content within this space.' => 'O autor deste conteúdo não tem permissão para criar este tipo de conteúdo neste espaço.',
    'The content can\'t be moved to its current space.' => 'O conteúdo não pode ser movido para o espaço atual.',
    'The content cannot be published!' => 'O conteúdo não pode ser publicado!',
    'The content has been archived.' => 'O conteúdo foi arquivado.',
    'The content has been deleted.' => 'O conteúdo foi apagado.',
    'The content has been successfully published.' => 'O conteúdo foi publicado com sucesso.',
    'The content has been unarchived.' => 'O conteúdo foi desarquivado.',
    'The given name is already in use.' => 'O nome informado já está em uso.',
    'The module {moduleName} is not enabled on the selected target space.' => 'O módulo {moduleName} não está ativado no espaço de destino selecionado.',
    'This action is disabled!' => 'Essa ação está desabilitada!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Este tipo de conteúdo não pode ser movido devido a uma configuração ausente do ID do módulo.',
    'This content type can\'t be moved.' => 'Este tipo de conteúdo não pode ser movido.',
    'This space is archived.' => 'Esse espaço está arquivado.',
    'This space is not visible!' => 'Esse espaço não é visível!',
    'Topics' => 'Tópicos',
    'Turn off notifications' => 'Desativar notificações',
    'Turn on notifications' => 'Ativar notificações',
    'Unarchive' => 'Desarquivar',
    'Unlock comments' => 'Desbloquear comentários',
    'Unpin' => 'Desprender',
    'Updated' => 'Atualizado',
    'Visible also to unregistered users' => 'Visível também para usuários não registrados',
    'Visible only to you' => 'Visível apenas para você',
    'Visible to all Space members' => 'Visível para todos os membros do Espaço',
    'Visible to all signed in users' => 'Visível para todos os usuários conectados',
    'Visible to friends of {displayName}' => 'Visível para amigos de {displayName}',
    'Visible to you and {displayName}' => 'Visível para você e {displayName}',
    'Visible to your friends' => 'Visível para seus amigos',
    'With attachments' => 'Com anexos de arquivos',
    'You cannot block the space owner!' => 'Você não pode bloquear o dono do espaço!',
    'You cannot block the user of the same container!' => 'Você não pode bloquear o usuário do mesmo container!',
    'You cannot block yourself!' => 'Você não pode bloquear você mesmo!',
    'You do not have the permission to move this content to the given space.' => 'Você não tem permissão para mover este conteúdo para o espaço fornecido.',
    'You do not have the permission to move this content.' => 'Você não tem permissão para mover este conteúdo.',
    'Your last edit state has been saved!' => 'Seu último estado de alteração foi salvo!',
    'in' => 'em',
    'Topic already exists globally.' => '',
    'Topic already in use in Spaces or on Profiles.' => '',
];
